import {
    getHydrographParameters,
    latestSelectedParameterValue
} from './hydrograph-parameters-selector';

describe('monitoring-location/selectors/hydrograph-parameters-selector', () => {

    describe('getHydrographParameters', () => {
        it('if state doesn\'t have hydrograph parameters, an empty object is returned', () => {
            expect(getHydrographParameters({})).toEqual({});
        });

        it('if state has hydrograph parameters, the data is returned', () => {
            expect(getHydrographParameters({
                hydrographParameters: {
                    '72255': {
                        parameterCode: '72255',
                        name: 'Mean water velocity for discharge computation, feet per second',
                        description: 'Mean water velocity for discharge computation, feet per second',
                        unit: 'ft/sec',
                        hasIVData: true,
                        latestValue: '0.45'
                    }
                }
            })).toEqual({
                '72255': {
                    parameterCode: '72255',
                    name: 'Mean water velocity for discharge computation, feet per second',
                    description: 'Mean water velocity for discharge computation, feet per second',
                    unit: 'ft/sec',
                    hasIVData: true,
                    latestValue: '0.45'
                }
            });
        });
    });

    describe('latestSelectedParameterValue', () => {
        it('if state doesn\'t have hydrograph parameters, null is returned', () => {
            expect(latestSelectedParameterValue({
                    hydrographState: {
                        selectedParameterCode: '00060'
                    }
            })).toEqual(null);
        });

        it('if state doesn\t have a selected parameter code, null is returned', () => {
            expect(latestSelectedParameterValue({
                hydrographParameters: {
                    '72255': {
                        parameterCode: '72255',
                        name: 'Mean water velocity for discharge computation, feet per second',
                        description: 'Mean water velocity for discharge computation, feet per second',
                        unit: 'ft/sec',
                        hasIVData: true,
                        latestValue: '0.45'
                    }
                },
                hydrographState: {
                    selectedParameterCode: ''
                }
            })).toEqual(null);
        });

        it('returns the latest selected parameter value', () => {
            expect(latestSelectedParameterValue({
                hydrographParameters: {
                    '72255': {
                        parameterCode: '72255',
                        name: 'Mean water velocity for discharge computation, feet per second',
                        description: 'Mean water velocity for discharge computation, feet per second',
                        unit: 'ft/sec',
                        hasIVData: true,
                        latestValue: '0.45'
                    }
                },
                hydrographState: {
                    selectedParameterCode: '72255'
                }
            })).toEqual('0.45');
        });

        it('returns null if there is no latest value', () => {
            expect(latestSelectedParameterValue({
                hydrographParameters: {
                    '72255': {
                        parameterCode: '72255',
                        name: 'Mean water velocity for discharge computation, feet per second',
                        description: 'Mean water velocity for discharge computation, feet per second',
                        unit: 'ft/sec',
                        hasIVData: true
                    }
                },
                hydrographState: {
                    selectedParameterCode: '72255'
                }
            })).toEqual(null);
        });
    });
});