import {select} from 'd3-selection';
import * as L from 'leaflet';

import {configureStore} from 'network/store';

import {createMapLegend} from './legend';


describe('component/map/legend module', () => {
    let control;
    let map;
    let store;

    beforeEach(() => {
        select('body').append('div')
            .attr('id', 'map');
        map = L.map('map', {
            center: [43.0, -100.0],
            zoom: 5
        });

        store = configureStore({
            networkData: {
                networkMonitoringLocations: []
            }
        });
        control = createMapLegend(map, store);
    });

    afterEach(() => {
        select('#map').remove();
    });

    describe('createMapLegend', () => {
        it('expect to create a legend with no markers if there is no data', () => {
            store = configureStore({
                networkData: {
                    networkMonitoringLocations: []
                }
            });
            control = createMapLegend(map, store);
            expect(control.getLegendListContainer().hasChildNodes()).toBe(false);
        });

        it('expect to create a legend with a marker is there is data', () => {
            store = configureStore({
                networkData: {
                    networkMonitoringLocations: [{
                        type: 'Feature',
                        id: 'USGS-343048093030401'
                    }, {
                        type: 'Feature',
                        id: 'USGS-343048093030402'
                    }]
                }
            });
            control = createMapLegend(map, store);
            expect(control.getLegendListContainer().childNodes).toHaveLength(1);
        });
    });
});
