import {mount} from '@vue/test-utils';

import USWDSAlert from './alert.vue';


describe('components/uswds/alert', () => {
    it('expects a success message', () => {
        const wrapper = mount(USWDSAlert, {
            slots: {
                default: '<p class="usa-alert__text">content</p>'
            },
            propsData: {
                alertType: 'success',
                alertTitle: 'This Alert'
            }
        });
        const wrapperClasses = wrapper.classes();
        expect(wrapper.find('.usa-alert__body').exists()).toBe(true);
        expect(wrapper.find('.usa-alert__heading').text()).toContain('This Alert');
        expect(wrapperClasses).toContain('usa-alert--success');
        expect(wrapperClasses).not.toContain('usa-alert--slim');
        expect(wrapperClasses).not.toContain('usa-alert--no-icon');
        expect(wrapper.find('.usa-alert__text').text()).toBe('content');
    });

    it('expects a error message with no alert icon', () => {
        const wrapper = mount(USWDSAlert, {
            slots: {
                default: '<p>content</p>'
            },
            props: {
                alertType: 'error',
                showAlertIcon: false
            }
        });


        expect(wrapper.find('.usa-alert__body').exists()).toBe(true);
        expect(wrapper.find('.usa-alert__heading').exists()).toBe(false);
        const wrapperClasses = wrapper.classes();
        expect(wrapperClasses).toContain('usa-alert--error');
        expect(wrapperClasses).toContain('usa-alert--no-icon');
    });

    it('expects a info message', () => {
        const wrapper = mount(USWDSAlert, {
            slots: {
                default: '<p>content</p>'
            },
            props: {
                alertType: 'info',
                alertTitle: 'Notice'
            }
        });

        expect(wrapper.find('.usa-alert__body').exists()).toBe(true);
        expect(wrapper.find('.usa-alert__body').text()).toContain('Notice');
        expect(wrapper.classes()).toContain('usa-alert--info');
    });

    it('expects that the alert component will be slim', () => {
        const wrapper = mount(USWDSAlert, {
            slots: {
                default: '<p>content</p>'
            },
            props: {
                alertType: 'info',
                slimAlert: true
            }
        });

        const wrapperClasses = wrapper.classes();
        expect(wrapperClasses).toContain('usa-alert--info');
        expect(wrapperClasses).toContain('usa-alert--slim');
    });

    it('expects no close button', () => {
        const wrapper = mount(USWDSAlert, {
            slots: {
                default: '<p>content</p>'
            },
            props: {
                alertType: 'info'
            }
        });

        expect(wrapper.findAll('button')).toHaveLength(0);
    });

    it('expects a close icon', () => {
        const wrapper = mount(USWDSAlert, {
            slots: {
                default: '<p>content</p>'
            },
            props: {
                alertType: 'info',
                showClose: true,
                staticRoot: '/fake/'
            }
        });
        expect(wrapper.findAll('.message-close')).toHaveLength(1);
        expect(wrapper.find('.message-close').html()).toContain('/fake/');
    });

    it('expects a click on the close button to emit event', async() => {
        const wrapper = mount(USWDSAlert, {
            slots: {
                default: '<p>content</p>'
            },
            props: {
                alertType: 'info',
                showClose: true
            }
        });
        expect(wrapper.findAll('.message-close')).toHaveLength(1);
        await wrapper.find('.message-close').trigger('click');
        expect(wrapper.emitted().closeAlert).toHaveLength(1);
    });
});
