import {mount} from '@vue/test-utils';

import USWDSCheckbox from './checkbox.vue';

describe('uswds-components/checkbox', () => {
    it('Expects a properly rendered unchecked USWDS checkbox', () => {
        const wrapper = mount(USWDSCheckbox, {
            props: {
                label: 'This checkbox',
                name: 'checkbox-name',
                value: 'yes',
                id: 'my-unique-id'
            }
        });

        const checkbox = wrapper.find('.usa-checkbox__input');
        const checkboxLabel = wrapper.find('.usa-checkbox__label');
        expect(checkbox.attributes('id')).toBe('my-unique-id');
        expect(checkbox.attributes('name')).toBe('checkbox-name');
        expect(checkbox.attributes('value')).toBe('yes');
        expect(checkbox.element.checked).toBe(false);
        expect(checkboxLabel.attributes('for')).toBe('my-unique-id');
        expect(checkboxLabel.text()).toBe('This checkbox');
    });

    it('Expects a checkbox that is initial checked', () => {
        const wrapper = mount(USWDSCheckbox, {
            props: {
                label: 'This checkbox',
                name: 'checkbox-name',
                value: 'yes',
                id: 'my-unique-id',
                isChecked: true
            }
        });

        const checkbox = wrapper.find('.usa-checkbox__input');
        expect(checkbox.element.checked).toBe(true);
    });

    it('Expect to emit a toggleCheckbox event if the checkbox is clicked', async() => {
        const wrapper = mount(USWDSCheckbox, {
            props: {
                label: 'This checkbox',
                name: 'checkbox-name',
                value: 'yes',
                id: 'my-unique-id'
            }
        });
        const checkbox = wrapper.find('.usa-checkbox__input');
        checkbox.setChecked(true);

        expect(wrapper.emitted('toggleCheckbox')[0][0]).toBe(true);

        checkbox.setChecked(false);

        expect(wrapper.emitted('toggleCheckbox')[1][0]).toBe(false);
    });

    it('Expect checkbox to be disabled when prop true', () => {
        const wrapper = mount(USWDSCheckbox, {
            props: {
                label: 'This checkbox',
                name: 'checkbox-name',
                value: 'yes',
                id: 'my-unique-id',
                isCheckboxDisabled: true
            }
        });
        const checkboxInput = wrapper.find('input');
        expect(checkboxInput.attributes('disabled')).toBeDefined();
    });

    it('Expect checkbox to be enabled by default', () => {
        const wrapper = mount(USWDSCheckbox, {
            props: {
                label: 'This checkbox',
                name: 'checkbox-name',
                value: 'yes',
                id: 'my-unique-id'
            }
        });
        const checkboxInput = wrapper.find('input');
        expect(checkboxInput.attributes('disabled')).not.toBeDefined();
    });
});
