import {shallowMount} from '@vue/test-utils';

import RadioButtonSet from './radio-button-set.vue';

describe('components/radio-button-set', () => {
    it('expects the buttons will match the props passed in', () => {
        const buttonList = [
            {
                id: 'button-one',
                label: 'Button one - choose me!',
                checked: true,
                actionValue: 'button one clicked'
            },
            {
                id: 'button-two',
                label: 'Button two - no, choose me!',
                checked: false,
                actionValue: 'button two clicked'
            }
        ];

        const wrapper = shallowMount(RadioButtonSet, {
            props: {
                'buttonSetName': 'test-set',
                'buttonList': buttonList,
                'legendText': 'A set of radio buttons'
            }
        });

        expect(wrapper.findAll('.usa-radio')).toHaveLength(2);
        const buttonOne = wrapper.findAll('.usa-radio').at(0);
        const buttonTwo = wrapper.findAll('.usa-radio').at(1);
        expect(buttonOne.attributes('checked')).valueOf(true);
        expect(buttonTwo.attributes('checked')).valueOf(false);

        expect(wrapper.findAll('input')).toHaveLength(2);
        const buttonInputOne = wrapper.findAll('input')[0];
        const buttonInputTwo = wrapper.findAll('input')[1];
        expect(buttonInputOne.attributes('id')).valueOf('button-one');
        expect(buttonInputTwo.attributes('id')).valueOf('button-two');
        expect(buttonInputOne.attributes('name')).valueOf('test-set');
        expect(buttonInputTwo.attributes('name')).valueOf('test-set');

        expect(wrapper.findAll('legend')).toHaveLength(1);
        expect(wrapper.findAll('legend')[0].text()).toBe('A set of radio buttons');
    });

    it('expects the buttons will emit the correct events', async() => {
        const buttonList = [
            {
                id: 'button-one',
                label: 'Button one - choose me!',
                checked: true,
                actionValue: 'button one clicked'
            },
            {
                id: 'button-two',
                label: 'Button two - no, choose me!',
                checked: false,
                actionValue: 'button two clicked'
            }
        ];

        const wrapper = shallowMount(RadioButtonSet, {
            props: {
                'buttonSetName': 'test-set',
                'buttonList': buttonList,
                'legendText': 'A set of radio buttons'
            }
        });

        expect(wrapper.findAll('input')).toHaveLength(2);

        const buttonOne = wrapper.findAll('input')[0];
        const buttonTwo = wrapper.findAll('input')[1];

        await buttonOne.trigger('click');
        await wrapper.vm.$nextTick();
        expect(wrapper.emitted().updateValue).toBeTruthy();
        expect(wrapper.emitted().updateValue).toEqual([['button one clicked']]);

        await buttonTwo.trigger('click');
        await wrapper.vm.$nextTick();
        expect(wrapper.emitted().updateValue).toEqual([['button one clicked'], ['button two clicked']]);
    });
});
