import config from 'ui/config';

/*
 * Fetch camera data for siteno and return the JSON data. If there is no meta
 * data or the call failed, return an Object with the success property set to false.
 * @param {String} siteno
 * @return {Promise} which resolves to an Object.
 */
export const fetchCameraMetaData = async function(siteno) {
    const url = `${config.MONITORING_LOCATION_CAMERA_ENDPOINT}/php/getSiteCameras.php?siteID=${siteno}`;
    try {
        const response = await fetch(url, {
            method: 'GET'
        });
        if (response.status === 200) {
            try {
                return await response.json();
            } catch (e) {
                return {
                    success: false
                };
            }
        } else {
            console.error(`Received bad status, ${response.status} for camera meta data at ${url}`);
            return {
                success: false
            };
        }
    } catch (error) {
        console.error(`Failed fetch for ${url}`);
        return {
            success: false
        };
    }
};
