import config from 'ui/config';

/*
 * Retrieve NOAA flood levels from the water watch endpointany for siteno
 * @param {String} siteno
 * @return {Promise} resolves to an Object containing the available flood levels or null if none.
 */
export const fetchFloodLevels = async function(siteno) {
    const url = `${config.WATERWATCH_ENDPOINT}/floodstage?site=${siteno}&format=json`;
    try {
        const response = await fetch(url, {
            method: 'GET'
        });
        if (response.status === 200) {
            const respJSON = await response.json();
            return respJSON.sites && respJSON.sites.length ? respJSON.sites[0] : null;
        } else {
            console.error(`Received bad status, ${response.status} for ${url}`);
            return null;
        }
    } catch (error) {
        console.error(`Failed fetch for ${url}`);
        return null;
    }
};
