import {enableFetchMocks, disableFetchMocks} from 'jest-fetch-mock';
import mockConsole from 'jest-mock-console';

import config from 'ui/config';
import {MOCK_SENSOR_THINGS_DATA} from 'ui/mock-service-data';

import {getSensorThingsURL, fetchDataFromSensorThings} from './sensor-things';

describe('web-services/sensor-things', () => {
    let restoreConsole;
    config.SENSOR_THINGS_ENDPOINT = 'fake-sensor-things-endpoint';

    beforeEach(() => {
        enableFetchMocks();
        restoreConsole = mockConsole();
    });

    afterEach(() => {
        disableFetchMocks();
        restoreConsole();
    });

    describe('getSensorThingsURL', () => {
        it('Expects url to contain combined agency and site number', () => {
            const result = getSensorThingsURL('USGS-01646500', '00065');
            expect(result).toContain('00065');
            expect(result).toContain('USGS-01646500');
        });
    });

    describe('fetchDataFromSensorThings', () => {
        beforeEach(() => {
            fetch.resetMocks();
        });

        it('Successful fetch returns a JSON object with threshold data', async() => {
            fetch.once(MOCK_SENSOR_THINGS_DATA, {status: 200});
            const resp = await fetchDataFromSensorThings('USGS-01646500', '00065');

            expect(resp).toEqual(JSON.parse(MOCK_SENSOR_THINGS_DATA));
        });

        it('Bad fetch returns an empty object', async() => {
            fetch.once('Internal server error', {status: 500});
            const resp = await fetchDataFromSensorThings('USGS-01646500', '00065');
            expect(resp).toEqual({});
        });
    });
});