const path = require('path');

const alias = require('@rollup/plugin-alias');
const replace = require('@rollup/plugin-replace');
const vue = require('@vitejs/plugin-vue');
const {defineConfig} = require('vite');

const entries = [
    {find: 'uswds-components', replacement: path.resolve(__dirname, 'node_modules/@uswds/uswds/packages')},
    {find: 'ui', replacement: path.resolve(__dirname, 'src/scripts/')},
    {find: 'ml', replacement: path.resolve(__dirname, 'src/scripts/monitoring-location')},
    {find: 'd3render', replacement: path.resolve(__dirname, 'src/scripts/d3-rendering')},
    {find: 'map', replacement: path.resolve(__dirname, 'src/scripts/monitoring-location/components/map')},
    {
        find: 'dvhydrograph',
        replacement: path.resolve(__dirname, 'src/scripts/monitoring-location/components/daily-value-hydrograph')
    },
    {
        find: 'ivhydrograph',
        replacement: path.resolve(__dirname, 'src/scripts/monitoring-location/components/hydrograph')
    },
    {find: 'network', replacement: path.resolve(__dirname, 'src/scripts/network')}
];

export default defineConfig(({command, mode}) => {
    return {
        base: '/dist/',
        plugins: [
            vue({
                isProduction: true,
                template: {
                    compilerOptions: {}
                }
            })
        ],
        build: {
            outDir: 'dist',
            assetsDir: '',
            manifest: 'manifest.json',
            emptyOutDir: false,
            sourcemap: mode === 'development',
            rollupOptions: {
                input: {
                    monitoringLocation: 'src/scripts/monitoring-location/index.js',
                    network: 'src/scripts/network/index.js'
                },
                plugins: [
                    alias({
                        entries: entries
                    }),
                    replace({
                        preventAssignment: true,
                        'process.env.NODE_ENV': JSON.stringify(mode)
                    })
                ],
                output: {
                    dir: 'dist',
                    entryFileNames: '[name].js'
                }
            }
        }
    };
});