"""
Class and functions for calling the Site Information Management Service (SIMS) for manually added location metadata
 and important operational information
"""
from requests import exceptions as request_exceptions, Session

from .. import app


class SiteInformationManagementService:
    # pylint: disable=too-few-public-methods, no-member
    """
    Provide access to the Site Information Management Service (SIMS) for manually added location metadata
    and important operational information
    """

    def __init__(self, endpoint):
        self.endpoint = endpoint
        self.session = Session()

    def get_sims_data(self, location_identifier):
        """
        Fetches Site Information Management Service data
        :param location_identifier - the unique combination of agency code and site number
        :return dictionary representing the available SIMS data for the location.
        """
        url = f"{self.endpoint}{location_identifier}"
        app.logger.debug(f'Requesting SIMS data from {url}')
        try:
            response = self.session.get(url)
        except (request_exceptions.Timeout, request_exceptions.ConnectionError) as err:
            app.logger.error(f'SIMS data request failed with reason: {repr(err)}')
            return {}

        app.logger.debug(f'Received SIMS data from {url}')
        if response.status_code != 200:
            return {}
        try:
            resp_json = response.json()
        except ValueError:
            return {}
        else:
            return resp_json
