"""
Tests for the Site Information Management Service (SIMS)
"""

import json

from requests_mock import Mocker

from ...services.sims import SiteInformationManagementService
from ..mock_test_data import MOCK_SIMS_RESPONSE

ENDPOINT = 'https://www.fake-sims.gov/api/'


def test_sims_response_with_location_identifier():
    sims = SiteInformationManagementService(ENDPOINT)
    location_identifier = 'USGS-1111111'
    with Mocker(session=sims.session) as session_mock:
        session_mock.get(f'{ENDPOINT}{location_identifier}', json=MOCK_SIMS_RESPONSE)
        result = sims.get_sims_data(location_identifier)

        assert session_mock.call_count == 1
        assert result == MOCK_SIMS_RESPONSE

def test_handling_bad_status_code():
    sims = SiteInformationManagementService(ENDPOINT)
    location_identifier = 'USGS-1111111'
    with Mocker(session=sims.session) as session_mock:
        session_mock.get(f'{ENDPOINT}{location_identifier}', status_code=404)
        result = sims.get_sims_data(location_identifier)

        assert session_mock.call_count == 1
        assert result == {}, 'Expected empty response'


def test_invalid_json():
    sims = SiteInformationManagementService(ENDPOINT)
    location_identifier = 'USGS-1111111'
    with Mocker(session=sims.session) as session_mock:
        session_mock.get(f'{ENDPOINT}{location_identifier}', status_code=200, text='{"x", "A",}')
        result = sims.get_sims_data(location_identifier)

        assert session_mock.call_count == 1
        assert result == {}, 'Expected empty response'
